Index: sync/internal_api/public/base/unique_position.h |
diff --git a/sync/internal_api/public/base/unique_position.h b/sync/internal_api/public/base/unique_position.h |
index b844b823d458bc6822865823a64d304e45de89cb..64dd9056ac4664957f7864adc059d276523ba3dd 100644 |
--- a/sync/internal_api/public/base/unique_position.h |
+++ b/sync/internal_api/public/base/unique_position.h |
@@ -5,9 +5,10 @@ |
#ifndef SYNC_INTERNAL_API_PUBLIC_BASE_UNIQUE_POSITION_H_ |
#define SYNC_INTERNAL_API_PUBLIC_BASE_UNIQUE_POSITION_H_ |
+#include <stdint.h> |
+ |
#include <string> |
-#include "base/basictypes.h" |
#include "sync/base/sync_export.h" |
namespace sync_pb { |
@@ -60,7 +61,7 @@ class SYNC_EXPORT_PRIVATE UniquePosition { |
// Creates a position with the given suffix. Ordering among positions created |
// from this function is the same as that of the integer parameters that were |
// passed in. |
- static UniquePosition FromInt64(int64 i, const std::string& suffix); |
+ static UniquePosition FromInt64(int64_t i, const std::string& suffix); |
// Returns a valid position. Its ordering is not defined. |
static UniquePosition InitialPosition(const std::string& suffix); |
@@ -93,10 +94,11 @@ class SYNC_EXPORT_PRIVATE UniquePosition { |
// Returns the suffix. |
std::string GetSuffixForTest() const; |
- // Performs a lossy conversion to an int64 position. Positions converted to |
- // and from int64s using this and the FromInt64 function should maintain their |
- // relative orderings unless the int64 values conflict. |
- int64 ToInt64() const; |
+ // Performs a lossy conversion to an int64_t position. Positions converted to |
+ // and from int64_ts using this and the FromInt64 function should maintain |
+ // their |
+ // relative orderings unless the int64_t values conflict. |
+ int64_t ToInt64() const; |
bool IsValid() const; |